@@ -8,4 +8,4 @@
 from noc.lib.test import ReportApplicationTestCase
 
 class reportsummaryTestCase(ReportApplicationTestCase):
-    posts=[{"vrf":1,"prefix":"0.0.0.0/0"}]
\ No newline at end of file
+    posts=[{"vrf":1,"prefix":"0.0.0.0/0","afi":"4"}]
\ No newline at end of file
