@@ -10,6 +10,7 @@ from django.http import HttpResponse,HttpResponseRedirect,HttpResponseForbidden,
 from django.shortcuts import render_to_response
 from django.utils.simplejson.encoder import JSONEncoder
 from django.db import connection
+from django.shortcuts import get_object_or_404
 from access import HasPerm
 from site import site
 from noc.lib.forms import NOCForm
@@ -34,6 +35,7 @@ class ApplicationBase(type):
 class Application(object):
     __metaclass__=ApplicationBase
     title="APPLICATION TITLE"
+    extra_permissions=[] # List of additional permissions, not related with views
     ##
     Form=NOCForm # Shortcut for form class
     config=settings.config
@@ -67,7 +69,7 @@ class Application(object):
     ## Send a message to user
     ##
     def message_user(self,request,message):
-        request.user.message_set.create(message=message)
+        request.user.message_set.create(message=unicode(message))
     ##
     ## Return path to named template
     ##
@@ -78,10 +80,16 @@ class Application(object):
             os.path.join("templates",template)
         ]
     ##
+    ## Shortcut to get_object_or_404
+    ##
+    def get_object_or_404(self,*args,**kwargs):
+        return get_object_or_404(*args,**kwargs)
+    
+    ##
     ## Render template within context
     ##
-    def render(self,request,template,dict={}):
-        return render_to_response(self.get_template_path(template),dict,
+    def render(self,request,template,dict={},**kwargs):
+        return render_to_response(self.get_template_path(template),dict if dict else kwargs,
             context_instance=RequestContext(request,dict={"app":self}))
     ##
     ## Render arpitrary Content-Type response
@@ -189,9 +197,13 @@ class Application(object):
     ##
     def get_permissions(self):
         p=set()
+        # View permissions from HasPerm
         for view in self.get_views():
             if isinstance(view.access,HasPerm):
                 p.add(view.access.get_permission(self))
+        # extra_permissions
+        for e in self.extra_permissions:
+            p.add(HasPerm(e).get_permission(self))
         return p
     ##
     ## Return a list of user access entries
@@ -222,3 +234,14 @@ class Application(object):
     #view_test.url_name="test"
     #view_test.access=permit
     #view_test.menu="Test"
+##
+## @view decorator
+##
+def view(url,access,url_name=None,menu=None):
+    def decorate(f):
+        f.url=url
+        f.url_name=url_name
+        f.access=access
+        f.menu=menu
+        return f
+    return decorate
