@@ -126,11 +126,12 @@ class FSM(object):
 ## StreamFSM also changes state on input stream conditions
 ##
 class StreamFSM(FSM):
+    MATCH_TAIL=0 # Match only N tailing bytes if not 0
     def __init__(self,async_throttle=None):
         self.patterns=[]
         self.in_buffer=""
         self.async_throttle=async_throttle # Limit to throttle synchronous check
-        self.feed_count=0 # Number of feeds from last state transition
+        self.feed_count=0 # Number of bytes fed from last state transition
         self.cleanup=None
         super(StreamFSM,self).__init__()
         
@@ -150,7 +151,11 @@ class StreamFSM(FSM):
         while self.in_buffer and self.patterns:
             matched=False
             for rx,event in self.patterns:
-                match=rx.search(self.in_buffer)
+                if self.MATCH_TAIL:
+                    offset=max(0, len(self.in_buffer)-self.MATCH_TAIL)
+                else:
+                    offset=0
+                match=rx.search(self.in_buffer, offset)
                 if match:
                     matched=True
                     self.feed_count=0 # Reset counter on event
@@ -165,7 +170,7 @@ class StreamFSM(FSM):
     
     def feed(self,data,cleanup=None):
         self.in_buffer+=data
-        self.feed_count+=1
+        self.feed_count+=len(data)
         self.cleanup=cleanup
         if not self.in_async_check():
             self.check_fsm()
@@ -174,3 +179,6 @@ class StreamFSM(FSM):
         if self.in_async_check():
             self.debug("Asynchronous check")
             self.check_fsm()
+    
+    def reset_async_check(self):
+        self.feed_count=0
