@@ -2,15 +2,28 @@
 ##----------------------------------------------------------------------
 ## Clean and lightweight non-blocking socket I/O implementation
 ##----------------------------------------------------------------------
-## Copyright (C) 2007-2009 The NOC Project
+## Copyright (C) 2007-2011 The NOC Project
 ## See LICENSE for details
 ##----------------------------------------------------------------------
+
+## Python modules
 from __future__ import with_statement
-import socket,select,errno,time,logging,pty,os,signal,subprocess,errno,sys
+import socket
+import select
+import errno
+import time
+import logging
+import pty
+import os
+import signal
+import subprocess
+import sys
+import fcntl
 from errno import *
 from threading import RLock
+## NOC modules
 from noc.lib.debug import error_report
-
+## Try to load SSL module
 try:
     import ssl
     HAS_SSL=True
@@ -152,6 +165,7 @@ def get_socket_error():
 ##
 class Socket(object):
     TTL=None # maximum time to live in seconds
+    READ_CHUNK=65536
     def __init__(self,factory,socket=None):
         self.factory=factory
         self.socket=socket
@@ -241,7 +255,8 @@ class Socket(object):
 ## remove them from buffer and return a list of parsed PDU (or empty list if not found)
 ## All parsed pdu are returned via callback method
 class Protocol(object):
-    def __init__(self,callback):
+    def __init__(self, parent, callback):
+        self.parent=parent
         self.callback=callback
         self.in_buffer=""
         
@@ -267,7 +282,9 @@ class LineProtocol(Protocol):
 ## Should not be used directly. Use SocketFactory.listen_tcp method instead
 ##
 class ListenTCPSocket(Socket):
-    def __init__(self,factory,address,port,socket_class,**kwargs):
+    def __init__(self,factory, address, port, socket_class, backlog=100, nconnects=None, **kwargs):
+        self.backlog=backlog
+        self.nconnects=nconnects
         Socket.__init__(self,factory)
         self.socket_class=socket_class
         self.address=address
@@ -281,7 +298,7 @@ class ListenTCPSocket(Socket):
         self.socket.setsockopt(socket.SOL_SOCKET,socket.SO_REUSEADDR,
             self.socket.getsockopt(socket.SOL_SOCKET,socket.SO_REUSEADDR) | 1)
         self.socket.bind((self.address,self.port))
-        self.socket.listen(5)
+        self.socket.listen(self.backlog)
         super(ListenTCPSocket,self).create_socket()
     
     def handle_read(self):
@@ -291,6 +308,10 @@ class ListenTCPSocket(Socket):
         else:
             logging.error("Refusing connection from %s"%addr[0])
             s.close()
+        if self.nconnects is not None:
+            self.nconnects-=1
+            if self.nconnects==0:
+                self.close()
     
     def log_label(self):
         return "%s(0x%x,%s:%s)"%(self.__class__.__name__,id(self),self.address,self.port)
@@ -312,7 +333,7 @@ class ListenUDPSocket(Socket):
         super(ListenUDPSocket,self).create_socket()
     
     def handle_read(self):
-        msg,transport_address=self.socket.recvfrom(8192)
+        msg,transport_address=self.socket.recvfrom(self.READ_CHUNK)
         if msg=="":
             return
         self.on_read(msg,transport_address[0],transport_address[1])
@@ -329,14 +350,18 @@ class ListenUDPSocket(Socket):
 ##
 class TCPSocket(Socket):
     protocol_class=None
-    def __init__(self,factory,socket=None):
-        super(TCPSocket,self).__init__(factory,socket)
+    def __init__(self, factory, socket=None):
+        super(TCPSocket,self).__init__(factory, socket)
         self.is_connected=False
-        self.s=socket
+        #self.s=socket
         self.out_buffer=""
         if self.protocol_class:
-            self.protocol=self.protocol_class(self.on_read)
+            self.protocol=self.protocol_class(self, self.on_read)
         self.in_shutdown=False
+    
+    def create_socket(self):
+        super(TCPSocket, self).create_socket()
+        self.adjust_buffers()
         
     def close(self,flush=False):
         if flush and len(self.out_buffer)>0:
@@ -366,6 +391,12 @@ class TCPSocket(Socket):
     def on_read(self,data): pass
     
     def on_connect(self): pass
+    
+    def adjust_buffers(self):
+        #print self.socket.getsockopt(socket.SOL_SOCKET, socket.SO_SNDBUF)
+        #self.socket.setsockopt(socket.SOL_SOCKET, socket.SO_SNDBUF, 1048576)
+        #self.socket.setsockopt(socket.SOL_SOCKET, socket.SO_RCVBUF, 1048576)
+        pass
 
 ##
 ## A socket wrapping accepted TCP connection.
@@ -389,11 +420,13 @@ class AcceptedTCPSocket(TCPSocket):
         
     def handle_read(self):
         try:
-            data=self.socket.recv(8192)
+            data=self.socket.recv(self.READ_CHUNK)
         except socket.error,why:
             if why[0] in (ECONNRESET,ENOTCONN,ESHUTDOWN):
                 self.close()
                 return
+            if why[0] in (EINTR, EAGAIN):
+                return
             raise socket.error, why
         if data=="":
             self.close()
@@ -405,7 +438,7 @@ class AcceptedTCPSocket(TCPSocket):
             self.on_read(data)
         
     def can_write(self):
-        return self.out_buffer
+        return len(self.out_buffer)>0
 ##
 ## SSL-enabled AcceptedTCPSocket
 ##
@@ -443,7 +476,7 @@ class AcceptedTCPSSLSocket(AcceptedTCPSocket):
 ## close(self)        - close socket (Also implies on_close(self) event)
 ##
 class ConnectedTCPSocket(TCPSocket):
-    def __init__(self,factory,address,port,local_address=None):
+    def __init__(self, factory, address, port, local_address=None):
         super(ConnectedTCPSocket,self).__init__(factory)
         self.address=address
         self.port=port
@@ -467,7 +500,7 @@ class ConnectedTCPSocket(TCPSocket):
             self.handle_connect()
             return
         try:
-            data=self.socket.recv(8192)
+            data=self.socket.recv(self.READ_CHUNK)
         except socket.error,why:
             if why[0]==ECONNREFUSED:
                 self.on_conn_refused()
@@ -476,6 +509,8 @@ class ConnectedTCPSocket(TCPSocket):
             if why[0] in (ECONNRESET,ENOTCONN,ESHUTDOWN):
                 self.close()
                 return
+            if why[0] in (EINTR, EAGAIN):
+                return
             raise socket.error,why
         if not data:
             self.close()
@@ -487,14 +522,15 @@ class ConnectedTCPSocket(TCPSocket):
             self.on_read(data)
     
     def can_write(self):
-        return self.out_buffer or not self.is_connected
+        return len(self.out_buffer)>0 or not self.is_connected
     
     def handle_write(self):
         if not self.is_connected:
             try:
                 self.socket.send("")
             except socket.error,why:
-                if why[0] in (EPIPE,ECONNREFUSED):
+                err_code=why[0]
+                if err_code in (EPIPE, ECONNREFUSED, ETIMEDOUT, EHOSTUNREACH, ENETUNREACH):
                     self.on_conn_refused()
                     self.close()
                     return
@@ -538,7 +574,7 @@ class UDPSocket(Socket):
         super(UDPSocket,self).create_socket()
     
     def can_write(self):
-        return self.out_buffer
+        return len(self.out_buffer)>0
     
     def handle_write(self):
         msg,addr=self.out_buffer.pop(0)
@@ -547,7 +583,7 @@ class UDPSocket(Socket):
 
     def handle_read(self):
         self.update_status()
-        msg,transport_address=self.socket.recvfrom(8192)
+        msg,transport_address=self.socket.recvfrom(self.READ_CHUNK)
         if msg=="":
             return
         self.on_read(msg,transport_address[0],transport_address[1])
@@ -564,25 +600,37 @@ class UDPSocket(Socket):
 class FileWrapper(object):
     def __init__(self,fileno):
         self._fileno=fileno
-        
+    
     def fileno(self):
         return self._fileno
-        
+    
     def recv(self, *args):
         return os.read(self._fileno, *args)
-        
+    
     def send(self, *args):
         return os.write(self._fileno, *args)
-        
+    
     read = recv
     
     write = send
     
     def close(self):
         os.close(self._fileno)
-        
-    def setblocking(self,status):
-        pass
+    
+    ##
+    ## Set blocking status
+    ## 0 - non-blocking mode
+    ## 1 - blocking mode
+    ##
+    def setblocking(self, status):
+        flags=fcntl.fcntl(self._fileno, fcntl.F_GETFL, 0)
+        if status:
+            flags = flags & (0xFFFFFFFF^os.O_NONBLOCK) # Blocking mode
+        else:
+            flags = flags | os.O_NONBLOCK # Nonblocking mode
+        fcntl.fcntl(self._fileno, fcntl.F_SETFL, flags)
+    
+
 ##
 ## PTY Socket Emulation
 ## Events: on_read, on_close
@@ -610,7 +658,7 @@ class PTYSocket(Socket):
     
     def handle_read(self):
         try:
-            data=self.socket.read(8192)
+            data=self.socket.read(self.READ_CHUNK)
         except OSError:
             self.close()
             return
@@ -621,7 +669,7 @@ class PTYSocket(Socket):
             self.close()
 
     def can_write(self):
-        return self.out_buffer
+        return len(self.out_buffer)>0
         
     def handle_write(self):
         sent=self.socket.send(self.out_buffer)
@@ -635,7 +683,7 @@ class PTYSocket(Socket):
         self.debug("write(%s)"%repr(msg))
         self.out_buffer+=msg
     
-    def close(self):
+    def close(self, flush=False):
         Socket.close(self)
         if self.pid is None:
             return
@@ -671,7 +719,7 @@ class PopenSocket(Socket):
 
     def handle_read(self):
         try:
-            data=self.socket.read(8192)
+            data=self.socket.read(self.READ_CHUNK)
         except OSError:
             self.close()
             return
@@ -681,7 +729,7 @@ class PopenSocket(Socket):
         else:
             self.close()
 
-    def close(self):
+    def close(self, flush=False):
         Socket.close(self)
 ##
 ## Socket Factory.
@@ -691,13 +739,97 @@ class PopenSocket(Socket):
 ## run         - main event loop
 ##
 class SocketFactory(object):
-    def __init__(self,tick_callback=None):
+    def __init__(self, tick_callback=None, polling_method=None, controller=None):
         self.sockets={}     # fileno -> socket
         self.socket_name={} # socket -> name
         self.name_socket={} # name -> socket
         self.new_sockets=[] # list of (socket,name)
         self.tick_callback=tick_callback
+        self.to_shutdown=False
         self.register_lock=RLock() # Guard for register/unregister operations
+        self.controller=controller # Reference to controlling daemon
+        self.get_active_sockets=None # Polling method
+        self.setup_poller(polling_method)
+        # Performance data
+        self.cnt_polls=0 # Number of polls
+    
+    # Shutdown factory and exit next loop
+    def shutdown(self):
+        logging.info("Shutting down the factory")
+        self.to_shutdown=True
+    
+    # Check select() available
+    def has_select(self):
+        return True
+    
+    # Check kevent/kqueue available
+    def has_kevent(self):
+        return False and hasattr(select, "kqueue")
+    
+    # Check poll() available
+    def has_poll(self):
+        return hasattr(select, "poll")
+    
+    # Check epoll() available
+    def has_epoll(self):
+        return hasattr(select, "epoll")
+
+    ##
+    ## Set up optimal polling function
+    ##
+    def setup_poller(self, polling_method=None):
+        # Enable select()
+        def setup_select_poller():
+            logging.debug("Set up select() poller")
+            self.get_active_sockets=self.get_active_select
+            self.polling_method="select"
+        
+        # Enable poll()
+        def setup_poll_poller():
+            logging.debug("Set up poll() poller")
+            self.get_active_sockets=self.get_active_poll
+            self.polling_method="poll"
+        
+        # Enable epoll()
+        def setup_epoll_poller():
+            logging.debug("Set up epoll() poller")
+            self.get_active_sockets=self.get_active_epoll
+            self.polling_method="epoll"
+        
+        # Enable kevent/kqueue
+        def setup_kevent_poller():
+            logging.debug("Set up kevent/kqueue poller")
+            self.get_active_sockets=self.get_active_kevent
+            self.polling_method="kevent"
+        
+        if polling_method is None:
+            # Read settings if available
+            try:
+                from noc.settings import config
+                polling_method=config.get("main", "polling_method")
+            except ImportError:
+                polling_method="select"
+        logging.debug("Setting up '%s' polling method"%polling_method)
+        if polling_method=="optimal":
+            # Detect possibilities
+            if self.has_kevent(): # kevent
+                setup_kevent_poller()
+            elif self.has_epoll():
+                setup_epoll_poller() # epoll
+            elif self.has_poll(): # poll
+                setup_poll_poller()
+            else: # Fallback to select
+                setup_select_poller()
+        elif polling_method=="kevent" and self.has_kevent():
+            setup_kevent_poller()
+        elif polling_method=="epoll" and self.has_epoll():
+            setup_epoll_poller()
+        elif polling_method=="poll" and self.has_poll():
+            setup_poll_poller()
+        else:
+            # Fallback to select
+            setup_select_poller()
+    
     ##
     ## Attack socket to the new_sockets list
     ##
@@ -705,6 +837,7 @@ class SocketFactory(object):
         logging.debug("register_socket(%s,%s)"%(socket,name))
         with self.register_lock:
             self.new_sockets+=[(socket,name)]
+    
     ##
     ## Remove socket from factory
     ##
@@ -718,6 +851,7 @@ class SocketFactory(object):
             self.name_socket.pop(old_name,None)
             if socket in self.new_sockets:
                 self.new_sockets.remove(socket)
+    
     ##
     ## Safe call of socket's method
     ## Returns call status (True/False)
@@ -739,6 +873,7 @@ class SocketFactory(object):
                 error_report()
             return False
         return True
+    
     ##
     ## Call socket's create_socket when necessary
     ## and add socket to the fabric
@@ -764,10 +899,10 @@ class SocketFactory(object):
             if name:
                 self.name_socket[name]=socket
         
-    def listen_tcp(self,address,port,socket_class,**kwargs):
+    def listen_tcp(self, address, port, socket_class, backlog=100, nconnects=None, **kwargs):
         if not issubclass(socket_class,AcceptedTCPSocket):
             raise "socket_class should be a AcceptedTCPSocket subclass"
-        l=ListenTCPSocket(self,address,port,socket_class,**kwargs)
+        l=ListenTCPSocket(self, address, port, socket_class, backlog, nconnects, **kwargs)
         l.set_name("listen-tcp-%s:%d"%(address,port))
         return l
     
@@ -802,39 +937,130 @@ class SocketFactory(object):
                 socket,name=self.new_sockets.pop(0)
                 self.init_socket(socket,name)
     
-    def loop(self,timeout=1):
+    ##
+    ## Generic loop wrapper.
+    ## Depends upon get_active_sockets() set up by constructor
+    ##
+    def loop(self, timeout=1):
         self.create_pending_sockets()
         if self.sockets:
-            with self.register_lock:
-                r=[f for f,s in self.sockets.items() if s.can_read()]
-                w=[f for f,s in self.sockets.items() if s.can_write()]
-            if r or w:
-                try:
-                    r,w,x=select.select(r,w,[],timeout)
-                except select.error,why:
-                    if why[0]==EINTR:
-                        return
-                    error_report()
-                    return
-                except:
-                    error_report()
-                    return
-                if r or w:
-                    # Write events processed before read events
-                    # to catch connection refused causes
-                    with self.register_lock:
-                        for f in w:
-                            if f in self.sockets:
-                                s=self.sockets[f]
-                                self.guarded_socket_call(s,s.handle_write)
-                        for f in r:
-                            if f in self.sockets:
-                                s=self.sockets[f]
-                                self.guarded_socket_call(s,s.handle_read)
-            else:
-                time.sleep(timeout)
+            r, w=self.get_active_sockets(timeout)
+            self.cnt_polls+=1
+            #logging.debug("Active sockets: Read=%s Write=%s"%(repr(r), repr(w)))
+            # Process write events before read to catch refused connections
+            for fd in w:
+                s=self.sockets.get(fd)
+                if s:
+                    self.guarded_socket_call(s, s.handle_write)
+            # Process read events
+            for fd in r:
+                s=self.sockets.get(fd)
+                if s:
+                    self.guarded_socket_call(s, s.handle_read)
         else:
+            # No socket initialized. Sleep to prevent CPU hogging
             time.sleep(timeout)
+    
+    ##
+    ## Straightforward select() implementation
+    ## Returns a list of (read fds, write fds)
+    ##
+    def get_active_select(self, timeout):
+        # Get read and write candidates
+        with self.register_lock:
+            r=[f for f, s in self.sockets.items() if s.can_read()]
+            w=[f for f, s in self.sockets.items() if s.can_write()]
+        # Poll socket status
+        try:
+            r, w, x=select.select(r, w, [], timeout)
+            return r, w
+        except select.error, why:
+            if why[0] not in (EINTR,):
+                error_report() # non-ignorable errors
+            return [], []
+        except KeyboardInterrupt:
+            logging.info("Got Ctrl+C, exiting")
+            sys.exit(0)
+        except:
+            error_report()
+            return [], []
+    
+    ##
+    ## poll() implementation
+    ##
+    def get_active_poll(self, timeout):
+        poll=select.poll()
+        # Get read and write candidates
+        with self.register_lock:
+            for f, s in self.sockets.items():
+                e=(select.POLLIN if s.can_read() else 0) | (select.POLLOUT if s.can_write() else 0)
+                if e:
+                    poll.register(f, e)
+        # Poll socket status
+        try:
+            events=poll.poll(timeout*1000) # ms->s
+        except select.error,why:
+            if why[0] not in (EINTR,):
+                error_report() # non-ignorable errors
+            return [], []
+        except:
+            return [], []
+        # Build result
+        rset=[fd for fd, e in events if e&(select.POLLIN|select.POLLHUP)]
+        wset=[fd for fd, e in events if e&select.POLLOUT]
+        return rset, wset
+    
+    ##
+    ## kevent/kqueue implementation
+    ## (dumb one)
+    ##
+    def get_active_kevent(self, timeout):
+        # Get read and write candidates
+        kqueue=select.kqueue()
+        events=[]
+        with self.register_lock:
+            for f, s in self.sockets.items():
+                if s.can_write():
+                    events+=[select.kevent(f, select.KQ_FILTER_WRITE, select.KQ_EV_ADD)]
+                if s.can_read():
+                    events+=[select.kevent(f, select.KQ_FILTER_READ, select.KQ_EV_ADD)]
+        # Register events with kqueue
+        kqueue.control(events, len(events), None)
+        # Poll events
+        rset=[]
+        wset=[]
+        for e in kqueue.control(None, len(events), timeout):
+            if e.filter&select.KQ_FILTER_WRITE:
+                wset+=[e.ident]
+            if e.filter&select.KQ_FILTER_READ:
+                rset+=[e.ident]
+        return rset, wset
+    
+    ##
+    ## poll() implementation
+    ##
+    def get_active_epoll(self, timeout):
+        epoll=select.epoll()
+        # Get read and write candidates
+        with self.register_lock:
+            for f, s in self.sockets.items():
+                e=(select.EPOLLIN if s.can_read() else 0) | (select.EPOLLOUT if s.can_write() else 0)
+                if e:
+                    epoll.register(f, e)
+        # Poll socket status
+        try:
+            events=epoll.poll(timeout)
+        except select.error,why:
+            if why[0] not in (EINTR,):
+                error_report() # non-ignorable errors
+            return [], []
+        except:
+            return [], []
+        # Build result
+        rset=[fd for fd, e in events if e&(select.EPOLLIN|select.EPOLLHUP)]
+        wset=[fd for fd, e in events if e&select.EPOLLOUT]
+        return rset, wset
+    
     ##
     def run(self,run_forever=False):
         logging.debug("Running socket factory")
@@ -848,7 +1074,7 @@ class SocketFactory(object):
                 time.sleep(1)
         last_tick=time.time()
         last_stale=time.time()
-        while cond():
+        while cond() and not self.to_shutdown:
             self.loop(1)
             t=time.time()
             if self.tick_callback and t-last_tick>=1:
@@ -861,3 +1087,4 @@ class SocketFactory(object):
             if t-last_stale>3:
                 self.close_stale()
                 last_stale=t
+    
