@@ -24,8 +24,9 @@ if __name__ == "__main__":
         # Initialize models
         os.environ["DJANGO_SETTINGS_MODULE"]="noc.settings"
         import noc.urls
-    if len(sys.argv)>1 and sys.argv[1]=="runserver":
+    if len(sys.argv)>1 and sys.argv[1] in ("runserver", "debug-script"):
         # Set loglevel to DEBUG
-        logging.root.setLevel(logging.DEBUG)
+        #logging.root.setLevel(logging.DEBUG)
+        logging.basicConfig(level=logging.DEBUG,format='%(asctime)s %(message)s')
     # Execute command
     execute_manager(settings)
