@@ -2,27 +2,40 @@
 ##----------------------------------------------------------------------
 ## Service Activator Daemon
 ##----------------------------------------------------------------------
-## Copyright (C) 2007-2009 The NOC Project
+## Copyright (C) 2007-2011 The NOC Project
 ## See LICENSE for details
 ##----------------------------------------------------------------------
 """
 """
+## Python modules
 from __future__ import with_statement
-import os,logging,pty,signal,time,re,sys,signal,Queue,cPickle,tempfile
+import os
+import logging
+import pty
+import signal
+import time
+import re
+import sys
+import signal
+import Queue
+import cPickle
+import tempfile
 from errno import ECONNREFUSED
+from threading import Lock
+## NOC modules
 from noc.sa.profiles import profile_registry
-from noc.sa.script import script_registry,ScriptSocket
+from noc.sa.script import script_registry
+from noc.sa.script.ssh.keys import Key
 from noc.sa.rpc import RPCSocket,file_hash,get_digest
 from noc.sa.protocols.sae_pb2 import *
 from noc.sa.protocols.pm_pb2 import *
 from noc.sa.servers import ServersHub
-from noc.lib.fileutils import safe_rewrite
+from noc.lib.fileutils import safe_rewrite, read_file
 from noc.lib.daemon import Daemon
 from noc.lib.fsm import FSM,check_state
 from noc.lib.nbsocket import ConnectedTCPSocket,ConnectedTCPSSLSocket,SocketFactory,PTYSocket,HAS_SSL,ListenUDPSocket,AcceptedTCPSocket,ListenTCPSocket
 from noc.lib.debug import DEBUG_CTX_CRASH_PREFIX
 from noc.lib.pmhash import pmhash
-from threading import Lock
 
 ##
 ##
@@ -119,10 +132,10 @@ class Service(SAEService):
 class ActivatorSocket(RPCSocket,ConnectedTCPSocket):
     def __init__(self,factory,address,port,local_address=None):
         ConnectedTCPSocket.__init__(self,factory,address,port,local_address)
-        RPCSocket.__init__(self,factory.activator.service)
+        RPCSocket.__init__(self,factory.controller.service)
         
     def activator_event(self,event):
-        self.factory.activator.event(event)
+        self.factory.controller.event(event)
     
     def on_connect(self):
         self.activator_event("connect")
@@ -138,10 +151,10 @@ class ActivatorSocket(RPCSocket,ConnectedTCPSocket):
 class ActivatorSSLSocket(RPCSocket,ConnectedTCPSSLSocket):
     def __init__(self,factory,address,port,local_address=None):
         ConnectedTCPSSLSocket.__init__(self,factory,address,port,local_address)
-        RPCSocket.__init__(self,factory.activator.service)
+        RPCSocket.__init__(self,factory.controller.service)
         
     def activator_event(self,event):
-        self.factory.activator.event(event)
+        self.factory.controller.event(event)
 
     def on_connect(self):
         self.activator_event("connect")
@@ -172,10 +185,8 @@ class FPingProbeSocket(PTYSocket):
         os.unlink(self.tmp_path)
         # fping issues duplicated addresses sometimes.
         # Remove duplicates
-        r={}
-        for u in [x.strip() for x in self.result.split("\n") if x.strip()]:
-            r[u]=None
-        self.callback(r.keys())
+        r=set([x.strip() for x in self.result.split("\n") if x.strip()])
+        self.callback(r)
         
     def on_read(self,data):
         self.result+=data
@@ -250,8 +261,7 @@ class Activator(Daemon,FSM):
         self.stand_alone_mode=self.config.get("activator","software_update") and not os.path.exists(os.path.join("sa","sae.py"))
         self.service=Service()
         self.service.activator=self
-        self.factory=SocketFactory(tick_callback=self.tick)
-        self.factory.activator=self
+        self.factory=SocketFactory(tick_callback=self.tick, controller=self)
         self.children={}
         self.ping_check_results={} # address -> last ping check result
         self.sae_stream=None
@@ -284,7 +294,29 @@ class Activator(Daemon,FSM):
         self.log_cli_sessions_path=self.config.get("main","log_cli_sessions_path")
         self.log_cli_sessions_ip_re=re.compile(self.config.get("main","log_cli_sessions_ip_re"))
         self.log_cli_sessions_script_re=re.compile(self.config.get("main","log_cli_sessions_script_re"))
-        
+        # SSH keys
+        self.ssh_public_key=None
+        self.ssh_private_key=None
+        self.load_ssh_keys()
+    
+    ##
+    ## Initialize ssh keys
+    ##
+    def load_ssh_keys(self):
+        private_path=self.config.get("ssh", "key")
+        public_path=private_path+".pub"
+        # Load keys
+        self.debug("Loading private ssh key from '%s'"%private_path)
+        s_priv=read_file(private_path)
+        self.debug("Loading public ssh key from '%s'"%public_path)
+        s_pub=read_file(public_path)
+        # Check all keys presend
+        if s_priv is None or s_pub is None:
+            self.error("Cannot find ssh keys. Generate one by 'python manage.py generate-ssh-keys' command")
+            os._exit(1)
+        self.ssh_public_key=Key.from_string(s_pub)
+        self.ssh_private_key=Key.from_string_private_noc(s_priv)
+    
     ##
     ## IDLE state 
     ##
