@@ -10,12 +10,15 @@
 import pprint
 import os
 ## Django modules
+from django.utils.translation import ugettext as _
+from django.utils.encoding import smart_unicode
 from django.contrib import admin
 from django.shortcuts import get_object_or_404
 from django import forms
 from django.db.models import Q
 from django.contrib.auth.models import User, Group
 from django.utils.safestring import SafeString
+from django.contrib.admin.filterspecs import FilterSpec, ChoicesFilterSpec
 ## NOC modules
 from noc.lib.app import ModelApplication, site, Permit, PermitSuperuser, HasPerm, PermissionDenied, view
 from noc.sa.models import *
@@ -63,6 +66,18 @@ def action_links(obj):
 action_links.short_description="Actions"
 action_links.allow_tags=True
 
+##
+## Display profile and platform
+##
+def profile(obj):
+    r=["<a href='?profile_name__exact=%s'>%s</a>"%(obj.profile_name, obj.profile_name)]
+    p=" ".join([x for x in [obj.get_attr("vendor"), obj.get_attr("platform")] if x])
+    if p:
+        r+=[p]
+    return "<br/>".join(r)
+profile.short_description=SafeString("Profile<br/>Platform")
+profile.allow_tags=True
+
 ##
 ## Display object status
 ##
@@ -84,6 +99,26 @@ def object_status(o):
 object_status.short_description=u"Status"
 object_status.allow_tags=True
 
+##
+## Profile filter
+##
+class ExistingChoicesFilterSpec(ChoicesFilterSpec):
+    def choices(self, cl):
+        yield {
+            "selected"    : self.lookup_val is None,
+            "query_string": cl.get_query_string({}, [self.lookup_kwarg]),
+            "display"     : _("All")}
+        
+        used=set(self.field.model.objects.distinct().values_list(self.field.name, flat=True))
+        for k, v in self.field.flatchoices:
+            if k in used:
+                yield {
+                    "selected"     : smart_unicode(k) == self.lookup_val,
+                    "query_string" : cl.get_query_string({self.lookup_kwarg: k}),
+                    "display"      : v}
+    
+
+FilterSpec.filter_specs.insert(0, (lambda f: getattr(f, "existing_choices_filter", False), ExistingChoicesFilterSpec))
 ##
 ## Administrative domain/activator
 ##
@@ -146,13 +181,13 @@ class ManagedObjectAdmin(admin.ModelAdmin):
             "fields": ("is_configuration_managed","repo_path")
         }),
         ("Rules",{
-            "fields": ("config_filter_rule", "config_validation_rule")
+            "fields": ("config_filter_rule", "config_diff_filter_rule", "config_validation_rule")
         }),
         ("Tags", {
             "fields": ("tags",)
         }),
     )
-    list_display=["name", object_status, "profile_name", "address",
+    list_display=["name", object_status, profile, "address",
                 domain_activator,
                 "description", "repo_path", action_links]
     list_filter=["is_managed","is_configuration_managed","activator","administrative_domain","profile_name"]
