@@ -6,14 +6,8 @@ from noc.sa.models import *
 
 class Migration:
     
-    def forwards(self, orm):
+    def forwards(self):
         db.execute("UPDATE sa_managedobject SET profile_name='AddPac.APOS' WHERE profile_name='VoiceFinder.AddPack'")
     
-    def backwards(self, orm):
+    def backwards(self):
         db.execute("UPDATE sa_managedobject SET profile_name='VoiceFinder.AddPack' WHERE profile_name='AddPac.APOS'")
-    
-    
-    models = {
-    }
-    
-    complete_apps = ['sa']
