@@ -31,6 +31,7 @@ from noc.sa.protocols.sae_pb2 import *
 from noc.lib.search import SearchResult
 from noc.lib.fields import PickledField, INETField, AutoCompleteTagsField
 from noc.lib.app.site import site
+from noc.lib.validators import check_re
 ##
 ## Register objects
 ##
@@ -107,13 +108,23 @@ class ManagedObject(models.Model):
     is_configuration_managed=models.BooleanField(_("Is Configuration Managed?"),default=True)
     repo_path=models.CharField(_("Repo Path"),max_length=128,blank=True,null=True)
     # pyRules
-    config_filter_rule=models.ForeignKey(PyRule, verbose_name="Config Filter pyRule", 
-            limit_choices_to={"interface": "IConfigFilter"}, null=True, blank=True, related_name="managed_object_config_filter_rule_set")
-    config_validation_rule=models.ForeignKey(PyRule, verbose_name="Config Validation pyRule",
-            limit_choices_to={"interface": "IConfigValidator"}, null=True, blank=True, related_name="managed_object_config_validation_rule_set")
+    config_filter_rule = models.ForeignKey(PyRule,
+            verbose_name="Config Filter pyRule", 
+            limit_choices_to={"interface": "IConfigFilter"},
+            null=True, blank=True, related_name="managed_object_config_filter_rule_set")
+    config_diff_filter_rule = models.ForeignKey(PyRule,
+            verbose_name=_("Config Diff Filter Rule"),
+            limit_choices_to={"interface": "IConfigDiffFilter"},
+            null=True, blank=True, related_name="managed_object_config_diff_rule_set")
+    config_validation_rule = models.ForeignKey(PyRule,
+            verbose_name="Config Validation pyRule",
+            limit_choices_to={"interface": "IConfigValidator"},
+            null=True, blank=True, related_name="managed_object_config_validation_rule_set")
     #
     tags=AutoCompleteTagsField(_("Tags"),null=True,blank=True)
     
+    profile_name.existing_choices_filter=True # Use special filter for profile
+    
     def __unicode__(self):
         return self.name
 
@@ -328,15 +339,15 @@ class ManagedObjectSelector(models.Model):
     description=models.TextField(_("Description"),blank=True,null=True)
     is_enabled=models.BooleanField(_("Is Enabled"),default=True)
     filter_id=models.IntegerField(_("Filter by ID"),null=True,blank=True)
-    filter_name=models.CharField(_("Filter by Name (REGEXP)"),max_length=256,null=True,blank=True)
+    filter_name=models.CharField(_("Filter by Name (REGEXP)"), max_length=256, null=True, blank=True, validators=[check_re])
     filter_profile=models.CharField(_("Filter by Profile"),max_length=64,null=True,blank=True,choices=profile_registry.choices)
-    filter_address=models.CharField(_("Filter by Address (REGEXP)"),max_length=256,null=True,blank=True)
+    filter_address=models.CharField(_("Filter by Address (REGEXP)"), max_length=256, null=True, blank=True, validators=[check_re])
     filter_administrative_domain=models.ForeignKey(AdministrativeDomain,verbose_name=_("Filter by Administrative Domain"),null=True,blank=True)
     filter_activator=models.ForeignKey(Activator,verbose_name=_("Filter by Activator"),null=True,blank=True)
     filter_user=models.CharField(_("Filter by User (REGEXP)"),max_length=256,null=True,blank=True)
-    filter_remote_path=models.CharField(_("Filter by Remote Path (REGEXP)"),max_length=256,null=True,blank=True)
-    filter_description=models.CharField(_("Filter by Description (REGEXP)"),max_length=256,null=True,blank=True)
-    filter_repo_path=models.CharField(_("Filter by Repo Path (REGEXP)"),max_length=256,null=True,blank=True)
+    filter_remote_path=models.CharField(_("Filter by Remote Path (REGEXP)"), max_length=256, null=True, blank=True, validators=[check_re])
+    filter_description=models.CharField(_("Filter by Description (REGEXP)"), max_length=256, null=True, blank=True, validators=[check_re])
+    filter_repo_path=models.CharField(_("Filter by Repo Path (REGEXP)"), max_length=256, null=True, blank=True, validators=[check_re])
     filter_tags=AutoCompleteTagsField(_("Filter By Tags"),null=True,blank=True)
     source_combine_method=models.CharField(_("Source Combine Method"),max_length=1,default="O",choices=[("A","AND"),("O","OR")])
     sources=models.ManyToManyField("ManagedObjectSelector",verbose_name=_("Sources"),symmetrical=False,null=True,blank=True)
@@ -373,6 +384,16 @@ class ManagedObjectSelector(models.Model):
         t_ids=TaggedItem.objects.get_intersection_by_model(ManagedObject,self.filter_tags).values_list("id",flat=True)
         if t_ids:
             q&=Q(id__in=t_ids)
+        # Restrict to attributes when necessary
+        m_ids=None
+        for s in  self.managedobjectselectorbyattribute_set.all():
+            ids = ManagedObjectAttribute.objects.filter(key__regex=s.key_re, value__regex=s.value_re).values_list("managed_object", flat=True)
+            if m_ids is None:
+                m_ids = set(ids)
+            else:
+                m_ids &= set(ids)
+        if m_ids is not None:
+            q &= Q(id__in=m_ids)
         # Apply filters
         r=ManagedObject.objects.filter(q)
         # Restrict to sources
@@ -416,6 +437,22 @@ class ManagedObjectSelector(models.Model):
         return self.managed_objects.filter(profile_name__in=sp)
     
 
+##
+## 
+##
+class ManagedObjectSelectorByAttribute(models.Model):
+    class Meta:
+        verbose_name = _("Managed Object Selector by Attribute")
+        verbose_name = _("Managed Object Selectors by Attribute")
+    
+    selector=models.ForeignKey(ManagedObjectSelector,verbose_name=_("Object Selector"))
+    key_re=models.CharField(_("Filter by key (REGEXP)"), max_length=256, validators=[check_re])
+    value_re=models.CharField(_("Filter by value (REGEXP)"), max_length=256, validators=[check_re])
+    
+    def __unicode__(self):
+        return u"%s: %s = %s"%(self.selector.name, self.key_re, self.value_re)
+    
+
 ##
 ## Managed objects access for user
 ##
