@@ -22,7 +22,7 @@ class Profile(noc.sa.profiles.Profile):
     command_enter_config="configure terminal"
     command_leave_config="exit"
     command_save_config="copy running-config startup-config\n"
-    pattern_prompt=r"^(?P<hostname>\S+?)(?:\(config[^\)]*\))?#"
+    pattern_prompt=r"^(?P<hostname>\S+?)(?:-\d+)?(?:\(config[^\)]*\))?#"
     requires_netmask_conversion=True
     convert_mac=noc.sa.profiles.Profile.convert_mac_to_cisco
     convert_interface_name=noc.sa.profiles.Profile.convert_interface_name_cisco
@@ -34,6 +34,23 @@ class Profile(noc.sa.profiles.Profile):
             p+=" le 32"
         return "no ip prefix-list %s\n"%name+"\n".join([p%x for x in pl])
     
+    ##
+    ## Perform session initialization
+    ## Process specific path parameters:
+    ## cluster:id - switch to cluster member
+    ##
+    def setup_session(self, script):
+        cluster_member=None
+        # Parse path parameters
+        for p in script.access_profile.path.split("/"):
+            if p.startswith("cluster:"):
+                cluster_member=p[8:].strip()
+        # Switch to cluster member, if necessary
+        if cluster_member:
+            script.debug("Switching to cluster member '%s'"%cluster_member)
+            script.cli("rc %s"%cluster_member)
+    
+
 ##
 ## uBR series selector
 ##
