@@ -7,16 +7,21 @@
 ##----------------------------------------------------------------------
 """
 """
-import noc.sa.script
-from noc.sa.interfaces import IGetChassisID
+## Python modules
 import re
-
-rx_mac=re.compile(r"([0-9a-f]{6}-[0-9a-f]{6})",re.IGNORECASE|re.MULTILINE|re.DOTALL)
-
-class Script(noc.sa.script.Script):
+## NOC modules
+from noc.sa.script import Script as NOCScript
+from noc.sa.interfaces import IGetChassisID
+##
+## HP.ProCurve.get_chassis_id
+##
+class Script(NOCScript):
     name="HP.ProCurve.get_chassis_id"
+    cache=True
     implements=[IGetChassisID]
+    
+    rx_mac=re.compile(r"([0-9a-f]{6}-[0-9a-f]{6})",re.IGNORECASE|re.MULTILINE|re.DOTALL)
     def execute(self):
         v=self.cli("show management")
-        match=rx_mac.search(v)
+        match=self.re_search(self.rx_mac, v)
         return match.group(1)
